summaryrefslogtreecommitdiff
path: root/gtk2_ardour/ardour_ui_dependents.cc
diff options
context:
space:
mode:
authorPaul Davis <paul@linuxaudiosystems.com>2017-09-18 12:39:17 -0400
committerPaul Davis <paul@linuxaudiosystems.com>2017-09-18 12:39:17 -0400
commit30b087ab3d28f1585987fa3f6ae006562ae192e3 (patch)
tree620ae0250b5d77f90a18f8c2b83be61e4fe7b0b5 /gtk2_ardour/ardour_ui_dependents.cc
parentcb956e3e480716a3efd280a5287bdd7bee1cedc5 (diff)
globally change all use of "frame" to refer to audio into "sample".
Generated by tools/f2s. Some hand-editing will be required in a few places to fix up comments related to timecode and video in order to keep the legible
Diffstat (limited to 'gtk2_ardour/ardour_ui_dependents.cc')
-rw-r--r--gtk2_ardour/ardour_ui_dependents.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/gtk2_ardour/ardour_ui_dependents.cc b/gtk2_ardour/ardour_ui_dependents.cc
index 87beab6b0e..307eac5451 100644
--- a/gtk2_ardour/ardour_ui_dependents.cc
+++ b/gtk2_ardour/ardour_ui_dependents.cc
@@ -296,9 +296,9 @@ ARDOUR_UI::setup_windows ()
main_vpacker.pack_start (top_packer, false, false);
- /* now add the transport frame to the top of main window */
+ /* now add the transport sample to the top of main window */
- main_vpacker.pack_start (transport_frame, false, false);
+ main_vpacker.pack_start (transport_sample, false, false);
main_vpacker.pack_start (_tabs, true, true);
#ifdef TOP_MENUBAR
@@ -336,7 +336,7 @@ ARDOUR_UI::setup_windows ()
*/
_main_window.add (main_vpacker);
- transport_frame.show_all ();
+ transport_sample.show_all ();
const XMLNode* mnode = main_window_settings ();